# pyhub-stubs
The unofficial stubbed MicroPython API for LEGO SPIKE Prime and LEGO Mindstorm Robot Inventor. This also includes the low-level modules like `hub`.

## Usage
This project is best working Visual Studio Code extension  [PeterStaev.lego-spikeprime-mindstorms-vscode](https://marketplace.visualstudio.com/items?itemName=PeterStaev.lego-spikeprime-mindstorms-vscode)

## Credits
This project is forked from https://github.com/fluffyhuskystudio/spike-prime-api (See `Credits` section from there as well)
